==> glfw-2.4.2.tar.gz: glfw-2.4.2/lib/x11/x11_enable.c <==
//========================================================================
// GLFW - An OpenGL framework
// File:        x11_enable.c
// Platform:    X11 (Unix)
// API version: 2.4
// Author:      Marcus Geelnard (marcus.geelnard at home.se)
// WWW:         http://glfw.sourceforge.net
//------------------------------------------------------------------------
// Copyright (c) 2002-2004 Marcus Geelnard
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source
//    distribution.
//
// Marcus Geelnard
// marcus.geelnard at home.se
//------------------------------------------------------------------------
// $Id: x11_enable.c,v 1.4 2004/02/14 21:01:45 marcus256 Exp $
//========================================================================

#include "internal.h"


//************************************************************************
//****               Platform implementation functions                ****
//************************************************************************

//========================================================================
// _glfwPlatformEnableSystemKeys() - Enable system keys
// _glfwPlatformDisableSystemKeys() - Disable system keys
//========================================================================

void _glfwPlatformEnableSystemKeys( void )
{
    // Not supported under X11 (yet)
}

void _glfwPlatformDisableSystemKeys( void )
{
    // Not supported under X11 (yet)
}

==> glfw_2.7.2.orig.tar.gz: glfw-2.7.2/lib/x11/x11_enable.c <==
//========================================================================
// GLFW - An OpenGL framework
// Platform:    X11 (Unix)
// API version: 2.7
// WWW:         http://www.glfw.org/
//------------------------------------------------------------------------
// Copyright (c) 2002-2006 Marcus Geelnard
// Copyright (c) 2006-2010 Camilla Berglund <elmindreda@elmindreda.org>
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source
//    distribution.
//
//========================================================================

#include "internal.h"


//************************************************************************
//****               Platform implementation functions                ****
//************************************************************************

//========================================================================
// Enable system keys
//========================================================================

void _glfwPlatformEnableSystemKeys( void )
{
    if( _glfwWin.keyboardGrabbed )
    {
        XUngrabKeyboard( _glfwLibrary.display, CurrentTime );
        _glfwWin.keyboardGrabbed = GL_FALSE;
    }
}

//========================================================================
// Disable system keys
//========================================================================

void _glfwPlatformDisableSystemKeys( void )
{
    if( XGrabKeyboard( _glfwLibrary.display, _glfwWin.window, True,
                        GrabModeAsync, GrabModeAsync, CurrentTime ) ==
        GrabSuccess )
    {
        _glfwWin.keyboardGrabbed = GL_TRUE;
    }
}
